import { jsx, jsxs } from "react/jsx-runtime";
import { createElement } from "react";
import { FormFieldset } from "./fieldComponents/FormField";
const RadioButtonItem = (props) => {
  let { inputId, attributes, optional, error } = props;
  const classNames = [
    "o3-form-input-radio-button",
    "o3-visually-hidden"
  ];
  if (error) {
    classNames.push("o3-form-input-error");
  }
  return /* @__PURE__ */ jsxs("div", { children: [
    /* @__PURE__ */ jsx(
      "input",
      {
        ...attributes,
        type: "radio",
        id: inputId,
        className: classNames.join(" "),
        required: !optional,
        "aria-required": !optional
      }
    ),
    /* @__PURE__ */ jsx("label", { htmlFor: inputId, className: "o3-form-input-radio-button__label", children: props.radioButtonLabel })
  ] });
};
const RadioButtonGroup = (props) => {
  const { children, ...restProps } = props;
  const radioGroupName = Math.random().toString(36).substring(7);
  return /* @__PURE__ */ jsx(FormFieldset, { ...restProps, children: children.map((child) => {
    const hasError = props.feedback?.errorElementIds?.includes(
      child.props.inputId
    );
    return /* @__PURE__ */ createElement(
      RadioButtonItem,
      {
        ...child.props,
        error: hasError,
        key: child.props.inputId,
        attributes: {
          ...child.props.attributes,
          name: radioGroupName
        }
      }
    );
  }) });
};
export {
  RadioButtonGroup,
  RadioButtonItem
};
