import { jsx, jsxs } from "react/jsx-runtime";
import { uidBuilder } from "@financial-times/o-utils";
import { Feedback } from "./Feedback";
const uniqueId = uidBuilder("o3-form");
const LabeledFormField = ({
  inputId,
  label,
  description,
  feedback,
  children,
  optional
}) => {
  const id = inputId || uniqueId("input_");
  const descriptionId = description ? uniqueId("description_") : void 0;
  const labelClasses = ["o3-form-field__label"];
  if (optional) {
    labelClasses.push("o3-form-field--optional");
  }
  return /* @__PURE__ */ jsxs("div", { className: "o3-form-field", children: [
    /* @__PURE__ */ jsx("label", { className: labelClasses.join(" "), htmlFor: id, children: label }),
    description && /* @__PURE__ */ jsx("span", { className: "o3-form-input__description", id: descriptionId, children: description }),
    children,
    feedback && /* @__PURE__ */ jsx(Feedback, { ...feedback })
  ] });
};
const TitledFormField = ({
  label,
  description,
  feedback,
  children,
  optional
}) => {
  const descriptionId = description ? uniqueId("description_") : void 0;
  const labelId = uniqueId("label_");
  const labelClasses = ["o3-form-field__title"];
  if (optional) {
    labelClasses.push("o3-form-field--optional");
  }
  return /* @__PURE__ */ jsxs("div", { className: "o3-form-field", children: [
    /* @__PURE__ */ jsx("span", { className: labelClasses.join(" "), id: labelId, children: label }),
    description && /* @__PURE__ */ jsx("span", { className: "o3-form-input__description", id: descriptionId, children: description }),
    children,
    feedback && /* @__PURE__ */ jsx(Feedback, { ...feedback })
  ] });
};
const FormFieldset = ({
  label,
  description,
  feedback,
  children,
  optional
}) => {
  const descriptionId = uniqueId("checkbox_");
  const labelClasses = ["o3-form-field__legend"];
  if (optional) {
    labelClasses.push("o3-form-field--optional");
  }
  return /* @__PURE__ */ jsxs("fieldset", { className: "o3-form-field", "aria-describedby": `${descriptionId}`, children: [
    /* @__PURE__ */ jsx("legend", { className: labelClasses.join(" "), children: label }),
    description && /* @__PURE__ */ jsx("span", { className: "o3-form-input__description", id: descriptionId, children: description }),
    children,
    feedback && /* @__PURE__ */ jsx(Feedback, { ...feedback })
  ] });
};
export {
  FormFieldset,
  LabeledFormField,
  TitledFormField
};
